



spectest-interp --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wasm-interp --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wasm-objdump --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wasm-opcodecnt --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wasm-validate --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wasm2c --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wasm2wat --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wast2json --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wat-desugar --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
wat2wasm --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
